/**
 * JASMINe
 * Copyright (C) 2008-2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DroolsUMOComponent.java 6042 2010-02-16 16:17:07Z jlegrand $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.naming.NamingException;

import org.ow2.jasmine.monitoring.eventswitch.beans.DroolsWorkingMemorySFBRemote;

/**
 * An UMO component to insert objects into a Drools working memory via EJB3.
 *
 * @author Loris Bouzonnet
 */
public class DroolsUMOComponent extends MuleEJB3Wrapper<DroolsWorkingMemorySFBRemote> {


    /**
     * A boolean used to prevent displaying warnings when the EJB is not ready
     */
    private boolean beanShouldBeReady = false;

    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public DroolsUMOComponent() {
        super(true);
    }

    /**
     * Insert object into a Drools working memory.
     * @param object Object to insert in the working memory
     */
    public void insertInWorkingMemory(final Object object) {

        ClassLoader currentClassLoader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(DroolsUMOComponent.class.getClassLoader());
        try {

            // Call the bean and save the event
            getBean().insert(object);

            // Mark the bean as working
            beanShouldBeReady = true;

        } catch (NamingException e) {
            if (beanShouldBeReady) {
                Logger.getLogger(DroolsUMOComponent.class.getName()).log(
                        Level.FINE,"EJBs are not ready ... the object is not inserted into the working memory");
            }
        } catch (IOException e) {
            if (beanShouldBeReady) {
                Logger.getLogger(DroolsUMOComponent.class.getName()).log(
                        Level.WARNING,"EJBs are not ready ... the object is not inserted into the working memory");
            }
        } finally {
            Thread.currentThread().setContextClassLoader(currentClassLoader);
        }
    }

}
