/**
 * JASMINe
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JasmineEventNotificationEJB3MergeWrapper.java 7648 2011-02-01 16:03:06Z jlegrand $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.naming.NamingException;

import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.event.beans.JasmineEventNotificationUpdate;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventNotificationSLBRemote;

/**
 * A wrapper class used to reach JasmineEventNotification objects via EJB3, and updates the right Notification.
 */
public class JasmineEventNotificationEJB3MergeWrapper extends MuleEJB3Wrapper<JasmineEventNotificationSLBRemote> {

    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public JasmineEventNotificationEJB3MergeWrapper() {
        super(true);
    }

    /**
     * Adds event detail in a stored {@link JasmineEventNotification JASMINe Event Notification}.
     *
     * @param jasmineEventNotification {@link JasmineEventNotification}
     */
    public void updateJasmineEventNotification(final JasmineEventNotificationUpdate p_JasmineEventNotificationUpdate) {
        ClassLoader currentClassLoader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(JasmineEventNotificationEJB3MergeWrapper.class.getClassLoader());

        try {
            getBean().updateEventNotification(p_JasmineEventNotificationUpdate);
        } catch (NamingException e) {
            Logger.getLogger(JasmineEventNotificationEJB3MergeWrapper.class.getName())
                .log(Level.WARNING, "EJBs are not ready ... the message is not persisted");
        } catch (IOException e) {
            Logger.getLogger(JasmineEventNotificationEJB3MergeWrapper.class.getName())
                .log(Level.WARNING, "EJBs are not ready ... the message is not persisted");
        } finally {
            Thread.currentThread().setContextClassLoader(currentClassLoader);
        }
    }

}
