/**
 * JASMINe
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JasmineEventNotificationUpdateDelayHandler.java 7648 2011-02-01 16:03:06Z jlegrand $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.util.Timer;
import java.util.TimerTask;

import org.mule.impl.message.ExceptionMessage;
import org.mule.umo.ComponentException;
import org.ow2.jasmine.event.beans.JasmineEventNotificationUpdate;
import org.ow2.jasmine.monitoring.eventswitch.tasks.DelayMessageTask;

/**
 * Mule endpoint triggering {@link JasmineEventNotificationUpdate} messages
 * whose processing ended with an exception.
 *
 * @author Guillaume Renault
 */
public class JasmineEventNotificationUpdateDelayHandler {

    /**
     *destination endpoint for the received messsage;
     */
    private String endpointURI;

    /**
     * Delay, in seconds.
     */
    private int delay;

    /**
     * The process of the message is delayed.
     *
     * @param exception the Mule exception.
     * @return the {@link JasmineEventNotificationUpdate} object that triggered
     *         the exception.
     */
    public JasmineEventNotificationUpdate delayMessage(final ExceptionMessage exception) {
        JasmineEventNotificationUpdate result = null;
        Object obj = ((ComponentException) exception.getException()).getUmoMessage().getAdapter().getPayload();
        if (obj instanceof JasmineEventNotificationUpdate) {
            result = (JasmineEventNotificationUpdate) obj;
            TimerTask task = new DelayMessageTask(result, endpointURI);
            new Timer().schedule(task, delay * 1000);
        }
        return result;
    }

    /**
     * @return the endpointURI
     */
    public final String getEndpointURI() {
        return endpointURI;
    }

    /**
     * @param endpointURI the endpointURI to set
     */
    public final void setEndpointURI(final String endpointURI) {
        this.endpointURI = endpointURI;
    }

    /**
     * @return the delay
     */
    public final int getDelay() {
        return delay;
    }

    /**
     * @param delay the delay to set
     */
    public final void setDelay(final int delay) {
        this.delay = delay;
    }

}
